| Title: | Tools for Easy Use of 'e-Stat', 'RESAS' API, Etc |
|---|---|
| Description: | Provides tools to use API such as 'e-Stat' (<https://www.e-stat.go.jp/>), the portal site for Japanese government statistics, and 'RESAS' (Regional Economy and Society Analyzing System, <https://resas.go.jp>). |
| Authors: | Mizuki Uchida [aut, cre] |
| Maintainer: | Mizuki Uchida <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.4.0 |
| Built: | 2026-05-16 09:12:55 UTC |
| Source: | https://github.com/uchidamizuki/jpstat |
The estat() gets the meta-information of a statistical table by using getMetaInfo of the 'e-Stat' API,
and returns an estat object that allows editing of meta-information by dplyr::filter() and dplyr::select().
estat( appId = deprecated(), statsDataId, lang = c("J", "E"), query = list(), path = "rest/3.0/app/json" )estat( appId = deprecated(), statsDataId, lang = c("J", "E"), query = list(), path = "rest/3.0/app/json" )
appId |
(Deprecated) an 'appId' of 'e-Stat' API. |
statsDataId |
A statistical data ID on 'e-Stat'. |
lang |
A language, Japanese ( |
query |
A list of additional queries. |
path |
An e-Stat API path. |
A estat object.
## Not run: estat("Your appId", "https://www.e-stat.go.jp/dbview?sid=0003433219") ## End(Not run)## Not run: estat("Your appId", "https://www.e-stat.go.jp/dbview?sid=0003433219") ## End(Not run)
Get table information for 'e-Stat' data
estat_table_info(x)estat_table_info(x)
x |
A |
A tbl_df of the table information.
Provides tools to use API such as 'e-Stat' (https://www.e-stat.go.jp/), the portal site for Japanese government statistics, and 'RESAS' (Regional Economy and Society Analyzing System, https://resas.go.jp).
Maintainer: Mizuki Uchida [email protected]
Useful links:
Report bugs at https://github.com/UchidaMizuki/jpstat/issues
resas( X_API_KEY = deprecated(), path, query = list(), to_snakecase = TRUE, names_sep = "/", rectangle = TRUE )resas( X_API_KEY = deprecated(), path, query = list(), to_snakecase = TRUE, names_sep = "/", rectangle = TRUE )
X_API_KEY |
(Deprecated) an 'X-API-KEY' of 'RESAS' API. |
path |
A 'RESAS' API path. |
query |
Additional queries. |
to_snakecase |
Whether the parameters and responses should be named as snake cases or not? |
names_sep |
A character that separates the names of the responses. |
rectangle |
Whether to rectangle the data or not? |
A resas object.
https://opendata.resas-portal.go.jp/
webland_trade(lang = c("ja", "en")) webland_city(lang = c("ja", "en"))webland_trade(lang = c("ja", "en")) webland_city(lang = c("ja", "en"))
lang |
Language. |
Collect data from the information on real estate transaction prices API provided by Japan's Ministry of Land, Infrastructure, Transport and Tourism.
webland_trade() a webland_trade object. By creating a query with itemise() and
applying collect(), The real estate transaction prices are collected.
webland_city() a webland_city object. Obtains a list of target
municipalities in the same way as webland_trade().
## Not run: # Collect trade data webland_trade() |> itemise(from = "20151", to = "20152", city_code = "13102") |> collect() # Collect target municipalities webland_city() |> itemise(pref_code = "13") |> collect() ## End(Not run)## Not run: # Collect trade data webland_trade() |> itemise(from = "20151", to = "20152", city_code = "13102") |> collect() # Collect target municipalities webland_city() |> itemise(pref_code = "13") |> collect() ## End(Not run)